@@ -21,10 +21,15 @@ from django.conf.urls.defaults import *
 
 urlpatterns = patterns(
     'lava_projects.views',
-    url('^$', 'project_root', name='lava.project.root'),
-    url(r'^\+list/$', 'project_list', name='lava.project.list'),
-    url(r'^\+register/$', 'project_register', name='lava.project.register'),
-    url(r'^(?P<identifier>[a-z0-9-]+)/$', 'project_detail', name='lava.project.detail'),
-    url(r'^(?P<identifier>[a-z0-9-]+)/\+update/$', 'project_update', name='lava.project.update'),
-    url(r'^(?P<identifier>[a-z0-9-]+)/\+rename/$', 'project_rename', name='lava.project.rename'),
-)
+    url('^$', 'project_root',
+        name='lava.project.root'),
+    url(r'^\+list/$', 'project_list',
+        name='lava.project.list'),
+    url(r'^\+register/$', 'project_register',
+        name='lava.project.register'),
+    url(r'^(?P<identifier>[a-z0-9-]+)/$', 'project_detail',
+        name='lava.project.detail'),
+    url(r'^(?P<identifier>[a-z0-9-]+)/\+update/$', 'project_update',
+        name='lava.project.update'),
+    url(r'^(?P<identifier>[a-z0-9-]+)/\+rename/$', 'project_rename',
+        name='lava.project.rename'))
